You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by ar...@apache.org on 2009/02/19 23:56:17 UTC

svn commit: r746046 - in /myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin: ./ src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/ src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/

Author: arobinson74
Date: Thu Feb 19 22:56:17 2009
New Revision: 746046

URL: http://svn.apache.org/viewvc?rev=746046&view=rev
Log:
Applying patch from Gary

Added:
    myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/
    myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml   (with props)
    myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml   (with props)
Modified:
    myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/pom.xml
    myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/JDeveloperMojo.java

Modified: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/pom.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/pom.xml?rev=746046&r1=746045&r2=746046&view=diff
==============================================================================
--- myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/pom.xml (original)
+++ myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/pom.xml Thu Feb 19 22:56:17 2009
@@ -15,7 +15,7 @@
     KIND, either express or implied.  See the License for the
     specific language governing permissions and limitations
     under the License.
-	   
+           
 -->
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
   <modelVersion>4.0.0</modelVersion>
@@ -29,6 +29,7 @@
   <groupId>org.apache.myfaces.trinidadbuild</groupId>
   <artifactId>maven-jdev-plugin</artifactId>
   <packaging>maven-plugin</packaging>
+  <version>1.2.8.1-SNAPSHOT</version>
   <name>Apache Trinidad Maven JDev Plugin</name>
 
   <dependencies>

Modified: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/JDeveloperMojo.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/JDeveloperMojo.java?rev=746046&r1=746045&r2=746046&view=diff
==============================================================================
--- myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml (added)
+++ myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml Thu Feb 19 22:56:17 2009
@@ -0,0 +1,215 @@
+<?xml version = '1.0' encoding = 'UTF-8'?>
+<!--
+  Copyright 2006-2009 The Apache Software Foundation.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+<jpr:project xmlns:jpr="http://xmlns.oracle.com/ide/project">
+   <hash n="component-versions">
+      <value n="oracle.adfdt.controller.adfc.source.migration.AdfControllerSchemaMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.adfc.source.migration.MoveMetadataResourcesAgainMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.common.migrator.ProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.jsf2.diagram.migrate.JsfNodeMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.struts.addin.db.ADFStrutsProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.struts.addin.StrutsProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.dvt.datapresdt.migration.DVTDataMapMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.model.ide.migration.ProjectMigrator" v="11.1.1.1.0.11.1.1"/>
+      <value n="oracle.adfdtinternal.model.ide.security.wizard.FormPageMigrator" v="11.1.1.0.0"/>
+      <value n="oracle.adfdtinternal.model.ide.security.wizard.JpsFilterMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.model.ide.xmled.migration.ADFNodeMigrator" v="11.1.1.1.0.5"/>
+      <value n="oracle.adfdtinternal.model.ide.xmled.migration.PageDefinitionParameterValueMigrator" v="11.1.1.1.0.5"/>
+      <value n="oracle.adfdtinternal.model.ide.xmled.migration.WebXmlMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.view.common.migration.wizards.MigrationHelper" v="11.1.1.1.0.3"/>
+      <value n="oracle.adfdtinternal.view.rich.binding.migration.JarResourceMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.view.rich.migration.ComponentIdNodeMigratorHelper" v="11.1.1.1.0.01"/>
+      <value n="oracle.adfdtinternal.view.rich.migration.LibraryVersionMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.bm.commonIde.ProjectUpgrader" v="11.1.1.1.0"/>
+      <value n="oracle.bm.migration.project.MigratorRegistryProjectUpgradeAdapter" v="11.1.1.1.0"/>
+      <value n="oracle.ide.model.Project" v="11.1.1.1.0"/>
+      <value n="oracle.ide.model.ResourcePathsMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jbo.dt.jclient.migrator.JCProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jbo.dt.jdevx.deployment.JbdProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jbo.dt.jdevx.ui.appnav.APProjectMigrator" v="11.1.1.1.0.5"/>
+      <value n="oracle.jbo.dt.migrate.ResourceBundlePathMigrator" v="11.1.1.1.0.5"/>
+      <value n="oracle.jbo.dt.migration.ServiceInterfaceMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdeveloper.ejb.EjbMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdeveloper.library.ProjectLibraryMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdeveloper.model.OutputDirectoryMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.deploy.DeploymentProfilesMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.deploy.jps.JpsDataMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.jsp.JspMigrator" v="11.1.1"/>
+      <value n="oracle.jdevimpl.offlinedb.migration.OfflineDBProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.offlinedb.migration.OfflineTransferMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.resourcebundle.XliffAddin$XliffMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.webapp.jsp.libraries.JspLibraryMigrator" v="11.1.1.1.4"/>
+      <value n="oracle.jdevimpl.webapp.WebAppContentSetNodeMigratorHelper" v="11.1.1"/>
+      <value n="oracle.jdevimpl.webapp.WebAppNodeMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.webservices.WebServicesMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.xml.wl.WeblogicMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.modeler.bmmigrate.management.Migration" v="11.1.1.1.0"/>
+      <value n="oracle.tip.tools.ide.fabric.addin.SCAProjectMigrator" v="11.1.1.1.0.06"/>
+      <value n="oracle.tip.tools.ide.pm.addin.migrator.PMProjectMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.toplink.workbench.addin.migration.PersistenceProjectMigrator" v="11.1.1.1.1"/>
+      <value n="oracle.toplink.workbench.addin.migration.TopLinkProjectMigrator" v="11.1.1.1.0"/>
+   </hash>
+   <list n="contentSets">
+      <string v="oracle.jdeveloper.model.PathsConfiguration/javaContentSet"/>
+      <string v="oracle.ide.model.ResourcePaths/resourcesContentSet"/>
+      <string v="oracle.jdeveloper.offlinedb.model.OfflineDBProjectSettings/offlineDBContentSet"/>
+      <string v="oracle.jdeveloper.model.J2eeSettings/webContentSet"/>
+      <string v="oracle.bm.commonIde.data.project.ModelerProjectSettings/modelersContentSet"/>
+      <string v="oracle.toplink.workbench.addin/toplinkContentSet"/>
+      <string v="oracle.adfdtinternal.model.ide.settings.ADFMSettings/adfmContentSet"/>
+      <string v="oracle.tip.tools.ide.fabric.addin.SCAContentSetProvider/sca-content"/>
+      <string v="oracle.mof.ide-tests/mofIdeTestsContentSet"/>
+   </list>
+      <hash n="oracle.adfdtinternal.model.ide.settings.ADFMSettings">
+      <hash n="adfmContentSet">
+         <list n="pattern-filters">
+            <string v="+**"/>
+         </list>
+         <list n="url-path">
+            <url path="adfmsrc/"/>
+         </list>
+      </hash>
+   </hash>
+   <hash n="oracle.bm.commonIde.data.project.ModelerProjectSettings">
+      <hash n="modelersContentSet">
+         <list n="url-path">
+            <url path="model/"/>
+         </list>
+      </hash>
+      <value n="modelersVersion" v="11.111"/>
+   </hash>
+   <hash n="oracle.ide.model.DependencyConfiguration">
+      <list n="dependencyList"/>
+   </hash>
+   <hash n="oracle.ide.model.ResourcePaths">
+      <hash n="resourcesContentSet">
+         <list n="pattern-filters">
+            <string v="+**"/>
+         </list>
+         <list n="url-path"/>
+      </hash>
+   </hash>
+   <hash n="oracle.jdeveloper.compiler.OjcConfiguration">
+      <value n="assertionsEnabled" v="true"/>
+      <value n="compiler.name" v="Ojc"/>
+      <list n="copyRes">
+         <string v=".java"/>
+      </list>
+      <value n="internalEncoding" v="Default"/>
+      <list n="Javac.commandline.optionlist">
+         <string v="-g"/>
+         <string v="-Xlint:all"/>
+         <string v="-Xlint:-cast"/>
+         <string v="-Xlint:-empty"/>
+         <string v="-Xlint:-fallthrough"/>
+         <string v="-Xlint:-path"/>
+         <string v="-Xlint:-serial"/>
+         <string v="-Xlint:-unchecked"/>
+      </list>
+      <list n="Ojc.commandline.optionlist">
+         <string v="-g"/>
+         <string v="-warn"/>
+         <string v="-nowarn:320"/>
+         <string v="-nowarn:372"/>
+         <string v="-nowarn:412"/>
+         <string v="-nowarn:413"/>
+         <string v="-nowarn:415"/>
+         <string v="-nowarn:486"/>
+         <string v="-nowarn:487"/>
+         <string v="-nowarn:489"/>
+         <string v="-nowarn:556"/>
+         <string v="-nowarn:558"/>
+         <string v="-nowarn:560"/>
+         <string v="-nowarn:561"/>
+         <string v="-nowarn:705"/>
+         <string v="-Xlint:-fallthrough"/>
+         <string v="-Xlint:-serial"/>
+         <string v="-Xlint:-unchecked"/>
+      </list>
+      <value n="reverseCopyRes" v="true"/>
+      <value n="showObjectDotStaticWarnings" v="true"/>
+      <value n="showPartialImportWarnings" v="true"/>
+      <value n="showUnusedImportWarnings" v="true"/>
+   </hash>
+   <hash n="oracle.jdeveloper.model.J2eeSettings">
+      <value n="j2eeWebAppName" v="maven-generated-webapp"/>
+      <value n="j2eeWebContextRoot" v="maven-generated-context-root"/>
+      <hash n="webContentSet">
+         <list n="url-path" />
+      </hash>
+   </hash>
+   <hash n="oracle.jdeveloper.model.PathsConfiguration">
+      <hash n="javaContentSet">
+        <list n="constituent-sets" />
+      </hash>
+   </hash>
+   <hash n="oracle.jdeveloper.offlinedb.model.OfflineDBProjectSettings">
+      <hash n="offlineDBContentSet">
+         <list n="pattern-filters">
+            <string v="+**"/>
+         </list>
+         <list n="url-path">
+            <url path="database/"/>
+         </list>
+      </hash>
+   </hash>
+   <hash n="oracle.jdeveloper.runner.RunConfigurations">
+      <hash n="runConfigurationDefinitions">
+         <hash n="Default">
+            <value n="compileBeforeRun" v="false"/>
+            <value n="custom" v="false"/>
+            <value n="name" v="Default"/>
+         </hash>
+      </hash>
+      <list n="runConfigurationList">
+         <string v="Default"/>
+      </list>
+   </hash>
+   <hash n="oracle.jdevimpl.config.JProjectLibraries">
+      <list n="exportedReferences"/>
+      <hash n="internalDefinitions">
+         <list n="libraryDefinitions" />
+      </hash>
+      <list n="libraryReferences"/>
+   </hash>
+   <hash n="oracle.jdevimpl.config.JProjectPaths"/>
+   <hash n="oracle.jdevimpl.webapp.jsp.libraries.model.ProjectTagLibraries">
+      <list n="tag-libraries"/>
+   </hash>
+   <hash n="oracle.tip.tools.ide.fabric.addin.SCAContentSetProvider">
+      <hash n="sca-content"/>
+   </hash>
+   <hash n="oracle.tip.tools.ide.pm.addin.PMProjectSettings">
+     <hash n="Integration_Content">
+       <list n="pattern-filters">
+         <string v="+**"/>
+       </list>
+     </hash>
+   </hash>
+   <hash n="oracle.toplink.workbench.addin">
+      <hash n="toplinkContentSet">
+         <list n="pattern-filters">
+            <string v="+**"/>
+         </list>
+         <list n="url-path">
+            <url path="toplink/"/>
+         </list>
+      </hash>
+   </hash>
+</jpr:project>
+
+
+

Propchange: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Added: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml?rev=746046&view=auto
==============================================================================
--- myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml (added)
+++ myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml Thu Feb 19 22:56:17 2009
@@ -0,0 +1,34 @@
+<?xml version = '1.0' encoding = 'UTF-8'?>
+<!--
+  Copyright 2006-2009 The Apache Software Foundation.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+<jws:workspace xmlns:jws="http://xmlns.oracle.com/ide/project">
+   <hash n="component-versions">
+      <value n="oracle.adf.share.dt.migration.jps.JaznCredStoreMigratorHelper" v="11.1.1.0.0;11.1.1.1.0"/>
+      <value n="oracle.adfdt.controller.adfc.source.migration.SavePointDataSourceForWLSMigrator" v="11.1.1.1.0"/>
+      <value n="oracle.adfdtinternal.model.ide.security.wizard.AdfSecurityMigrator" v="11.1.1.0.0;11.1.1.1.0.13"/>
+      <value n="oracle.ide.model.Project" v="10.1.3.0.4;11.1.1.0.0;11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.deploy.ear.OarMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.deploy.mar.MarMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.jdevimpl.runner.oc4j.EmbeddedServerMigratorHelper" v="11.1.1.0.0"/>
+      <value n="oracle.jdevimpl.webservices.WebServicesMigratorHelper" v="11.1.1.0.0"/>
+      <value n="oracle.jdevimpl.xml.oc4j.ds.DataSourcesMigratorHelper" v="11.1.1.0.0"/>
+      <value n="oracle.jdevimpl.xml.oc4j.jps.JpsConfigMigratorHelper" v="11.1.1.0.0;11.1.1.1.0.1"/>
+      <value n="oracle.jdevimpl.xml.wl.WeblogicMigratorHelper" v="11.1.1.1.0"/>
+      <value n="oracle.mds.internal.dt.ide.migrator.MDSConfigMigratorHelper" v="11.1.1.0.0;11.1.1.1.0"/>
+      <value n="oracle.webcenter.internal.dt.migration.WebCenterWorkspaceMigrator" v="11.1.1.0.0"/>
+   </hash>
+   <list n="listOfChildren" />
+</jws:workspace>

Propchange: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/workspace.xml
------------------------------------------------------------------------------
    svn:eol-style = native
--- myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/JDeveloperMojo.java (original)
+++ myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/java/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/JDeveloperMojo.java Thu Feb 19 22:56:17 2009
@@ -168,6 +168,13 @@
   private File[] sourceRoots;
 
   /**
+   * Does project have tests? Used to determine if the
+   * maven-jdev-plugin needs to create a <project name>-test.jpr
+   * @parameter expression="${jdev.project.has.tests}" default-value="false"
+   */
+  private boolean projectHasTests;
+  
+  /**
    * List of source root directories for the test project
    * @parameter
    */
@@ -241,10 +248,9 @@
   private List reactorProjects;
 
   /**
    * Tag library directory used by each distributed tag library
    *
    * @parameter expression="${jdev.tag.lib.dir}"
-   *            default-value="@oracle.home@lib/java/shared/oracle.jsf/1.2/jsf-ri.jar!/META-INF"
    */
   private String tagLibDirectory;
 
@@ -261,6 +267,18 @@
     throws MojoExecutionException
   {
     _parseRelease();
+
+    if (_releaseMajor >= 11)
+    {
+      tagLibDirectory = 
+        "@oracle.home@/modules/oracle.jsf_1.2.9/glassfish.jsf_1.2.9.0.jar!/META-INF";
+    }
+    else
+    {
+      tagLibDirectory =
+        "@oracle.home@lib/java/shared/oracle.jsf/1.2/jsf-ri.jar!/META-INF";
+    }
+    
     try
     {
       generateWorkspace();
@@ -364,7 +382,7 @@
   private void generateTestProject()
     throws IOException, MojoExecutionException
   {
-    if (!"pom".equals(project.getPackaging()))
+    if (!"pom".equals(project.getPackaging()) && projectHasTests)
     {
       File projectFile = getJProjectTestFile(project);
 
@@ -394,12 +412,9 @@
       List compileSourceRoots =
         executionProject.getTestCompileSourceRoots();
 
-      if (testSourceRoots != null)
+      for (int i = 0; i < testSourceRoots.length; i++)
       {
-        for (int i = 0; i < testSourceRoots.length; i++)
-        {
-          compileSourceRoots.add(testSourceRoots[i].getAbsolutePath());
-        }
+        compileSourceRoots.add(testSourceRoots[i].getAbsolutePath());
       }
 
       List compileResourceRoots = executionProject.getTestResources();
@@ -449,8 +464,12 @@
       replaceParameters(projectName, projectDOM);
       writeDOM(projectFile, projectDOM);
 
-      if ("war".equals(packaging))
+      /* Not needed in release 11 where .tld files are obtained
+      ** From jar's META-INF dir, not in WEB-INF dir as in v10
+      */
+      if ( (_releaseMajor < 11) && ("war".equals(packaging)) )
         copyTagLibraries(projectDir, dependencies, artifacts);
+
     }
     catch (XmlPullParserException e)
     {
@@ -474,7 +493,16 @@
     for (Iterator i = project.getCollectedProjects().iterator(); i.hasNext(); )
     {
       MavenProject collectedProject = (MavenProject) i.next();
+      boolean projHasTests = false;
 
+      // Added in V11
+      if (_releaseMajor < 11)
+      {
+        Properties props = collectedProject.getProperties();
+        String hasTests = (String)props.get(_PROPERTY_HAS_TESTS);
+        projHasTests = "true".equalsIgnoreCase(hasTests);
+      }
+      
       // if a child project is also a workspace, then don't 
       // put it in the .jws file.  It will have its own .jws
       // file.
@@ -486,8 +514,21 @@
                                                      projectFile));
   
         File testProjectFile = getJProjectTestFile(collectedProject);
-        targetDOM.addChild(createProjectReferenceDOM(workspaceDir,
-                                                     testProjectFile));
+
+        /*
+        ** In V11, we don't create a <projname>-test.jpr if 
+        ** a project does not have any tests.
+        */
+        if ( (_releaseMajor >= 11) && projHasTests)
+        {
+          targetDOM.addChild(createProjectReferenceDOM(workspaceDir, 
+                                                       testProjectFile));
+        }
+        else
+        {
+          targetDOM.addChild(createProjectReferenceDOM(workspaceDir, 
+                                                       testProjectFile));
+        }      
       }
     }
 
@@ -1000,13 +1041,12 @@
     }
   }
 
-
   private void replaceTagLibraries(Xpp3Dom projectDOM)
     throws XmlPullParserException
   {
     // This boolean is set by specifying the jdev.plugin.add.taglibs
     // property at the top of a project's pom file.  There are projects
-    // that don't need taglibs in their .jpr files to compile and this
+    // that don'1035t need taglibs in their .jpr files to compile and this
     // allows them to be excluded.
     if (!_addTagLibs)
       return;
@@ -1032,7 +1072,7 @@
     //  <value n="jspVersion" v="2.1"></value>
     //  <value n="name" v="JSF HTML"></value>
     //
-    //  <value n="tldURL" v="@oracle.home@lib/java/shared/oracle.jsf/1.2/jsf-ri.jar!/META-INF/html_basic.tld"></value>
+    //  <value n="tldURL" v="@oracle.home@/jdeveloper/modules/oracle.jsf_1.2.9/glassfish.jsf_1.2.9.0.jar!/META-INF"></value>        
     //  <value n="URI" v="http://java.sun.com/jsf/html"></value>
     //  <value n="version" v="1.2"></value>
     //</hash>
@@ -1145,7 +1185,10 @@
       replaceDefaultTagLibraries(projectDOM, targetLibsDOM);
     }
 
-    replaceLocalTagLibraries(targetLibsDOM);
+    // Tag libraries are obtained from the META-INF dir of the 
+    // jar files in the class path for V11.
+    if (_releaseMajor < 11)
+      replaceLocalTagLibraries(targetLibsDOM);
 
     // First, add JSP Runtime dependency if src/main/webapp exists
     // TODO: use a better merge algorithm
@@ -1785,4 +1828,6 @@
   private static final String _PROPERTY_ADD_LIBRARY = "jdev.plugin.add.libraries";
   private static final String _PROPERTY_ADD_TAGLIBS = "jdev.plugin.add.taglibs";
 
+  // Does nothing in v10.1.3
+  private static final String _PROPERTY_HAS_TESTS   = "jdev.project.has.tests";
 }
@@ -241,10 +248,9 @@
 
   /**
-   * Tag library directory used by each distributed tag library
+   * Tag library directory used by each distributed jsf tag library
    *
    * @parameter expression="${jdev.tag.lib.dir}"

Added: myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad-maven/branches/gkind-1.2.8.1-branch/maven-jdev-plugin/src/main/resources/org/apache/myfaces/trinidadbuild/plugin/jdeveloper/11.1.1.1.0/project.xml?rev=746046&view=auto
==============================================================================